==> haskell-persistent-2.6.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.6.1
id: persistent-2.6.1-G1ySI0gYR5jBJqWNDOlavM
key: persistent-2.6.1-G1ySI0gYR5jBJqWNDOlavM
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util Database.Persist.Sql.Types.Internal
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: 3c4e5d4e82a70a839dca50bb684e0cf1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/persistent-2.6.1
hs-libraries: HSpersistent-2.6.1-G1ySI0gYR5jBJqWNDOlavM
depends:
    aeson-1.0.2.1-12Tr6G2d7dgKxXx9Jv4gDD
    attoparsec-0.13.1.0-A4pUaeqQWkyDZOYwXw4PvN base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    http-api-data-0.3.5-FQELOjH2uHJHZkd7koPyb2
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.22-D2zkOupoBx0CaDUOC8bP1U
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    resource-pool-0.2.3.2-2NlSWHVeNqY4r3aqgFzumd
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.11-ICV8fOXZrxLGwVNBrNLr5f
    silently-1.2.5-Ek776fxSdtm4h8aXqt6CNw
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.6.1-20-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.6.1
id: persistent-2.6.1-Hejv5pqH6vqGdetNgBSkWw
key: persistent-2.6.1-Hejv5pqH6vqGdetNgBSkWw
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util Database.Persist.Sql.Types.Internal
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: 22df8685bfad43020351eddd5bae4b95
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/persistent-2.6.1
hs-libraries: HSpersistent-2.6.1-Hejv5pqH6vqGdetNgBSkWw
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    http-api-data-0.3.7-Fc5sVc0DoAABTSoF3nF1TP
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.24-Bbs87pbgXTxINqvuVr3oBE
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    resource-pool-0.2.3.2-1XRv9O8VAWTKrnDtjaPppU
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    silently-1.2.5-Ek776fxSdtm4h8aXqt6CNw
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
